pub struct Module {
pub name: String,
pub block_cooldown: Option<u32>,
pub methods: Vec<Method>,
}Expand description
A TRN permission topping module
Fields
name: Stringblock_cooldown: Option<u32>methods: Vec<Method>Implementations
Sourceimpl Module
impl Module
pub fn new(name: &str) -> Self
pub fn block_cooldown(self, block_cooldown: u32) -> Self
pub fn methods(self, methods: Vec<Method>) -> Self
Sourcepub fn get_method(&self, method: &str) -> Option<&Method>
pub fn get_method(&self, method: &str) -> Option<&Method>
Returns the method, if it exists in the Module Wildcard methods have lower priority than defined methods